@@ -1,6 +1,7 @@
 import importlib
 import sys
 
+import pkg_resources
 from modelstore.models.common import save_json
 from modelstore.utils.log import logger
 
@@ -11,16 +12,29 @@ _MODEL_TYPE_FILE = "model-info.json"
 
 def _get_version(modname: str) -> str:
     try:
+        if modname == "pickle":
+            # pylint: disable=import-outside-toplevel
+            import pickle
+
+            return pickle.format_version
         if modname in sys.modules:
             mod = sys.modules[modname]
         else:
+            logger.debug("Trying to import: %s", modname)
             mod = importlib.import_module(modname)
         return mod.__version__
+    except AttributeError:
+        try:
+            #  Annoy does not have a __version__
+            return pkg_resources.get_distribution(modname).version
+        except Exception:
+            logger.debug("Unable to get %s's version", modname)
+            return None
     except ImportError:
         logger.debug("%s is not installed.", modname)
         return None
     except Exception:
-        logger.error("Error importing %s.", modname)
+        logger.error("Error importing: %s.", modname)
         return None
 
 
