@@ -16,13 +16,11 @@ from functools import partial
 from typing import Any
 
 from modelstore.models.common import save_json
-from modelstore.models.modelmanager import ModelManager
+from modelstore.models.model_manager import ModelManager
+from modelstore.storage.storage import CloudStorage
 from modelstore.utils.log import logger
 
 _MODEL_PREFIX = "model.{}"
-MODEL_JSON = _MODEL_PREFIX.format("json")
-MODEL_CBM = _MODEL_PREFIX.format(".cbm")
-MODEL_ONNX = _MODEL_PREFIX.format("onnx")
 MODEL_ATTRIBUTES = "model_attributes.json"
 
 
@@ -39,8 +37,12 @@ class CatBoostManager(ModelManager):
     https://catboost.ai/docs/concepts/apply-onnx-ml.html
     """
 
-    @classmethod
-    def required_dependencies(cls) -> list:
+    NAME = "catboost"
+
+    def __init__(self, storage: CloudStorage = None):
+        super().__init__(self.NAME, storage)
+
+    def required_dependencies(self) -> list:
         return ["catboost", "onnxruntime"]
 
     def _required_kwargs(self):
@@ -52,33 +54,63 @@ class CatBoostManager(ModelManager):
 
         return isinstance(kwargs.get("model"), catboost.CatBoost)
 
-    def _model_info(self, **kwargs) -> dict:
-        """ Returns meta-data about the model's type """
-        return {"library": "catboost", "type": type(kwargs["model"]).__name__}
-
-    def _model_data(self, **kwargs) -> dict:
-        """ Returns meta-data about the data used to train the model """
-        return {}
-
     def _get_functions(self, **kwargs) -> list:
         if not self.matches_with(**kwargs):
             raise TypeError("Model is not a CatBoost model!")
 
+        # pool parameter, from the catboost docs:
+        # The dataset previously used for training.
+        # This parameter is required if the model contains categorical features and the output format is cpp, python, or JSON.
         return [
-            partial(save_model, model=kwargs["model"], fmt="json"),
-            partial(save_model, model=kwargs["model"], fmt="cbm"),
-            partial(save_model, model=kwargs["model"], fmt="onnx"),
+            partial(
+                save_model,
+                model=kwargs["model"],
+                fmt="json",
+                pool=kwargs.get("pool"),
+            ),
+            partial(
+                save_model,
+                model=kwargs["model"],
+                fmt="cbm",
+                pool=kwargs.get("pool"),
+            ),
+            # onnx: only datasets without categorical features are currently supported
+            partial(
+                save_model,
+                model=kwargs["model"],
+                fmt="onnx",
+                pool=kwargs.get("pool"),
+            ),
             partial(dump_attributes, model=kwargs["model"]),
         ]
 
     def _get_params(self, **kwargs) -> dict:
         """
-        Returns a dictionary containing any model parameters
-        that are available
         https://catboost.ai/docs/concepts/python-reference_catboost_get_params.html
         """
         return kwargs["model"].get_params()
 
+    def load(self, model_path: str, meta_data: dict) -> Any:
+        # pylint: disable=import-outside-toplevel
+        import catboost
+
+        model_types = {
+            "CatBoostRegressor": catboost.CatBoostRegressor,
+            "CatBoostClassifier": catboost.CatBoostClassifier,
+        }
+        model_type = self._get_model_type(meta_data)
+        if model_type not in model_types:
+            raise ValueError(f"Cannot load catboost model type: {model_type}")
+
+        logger.debug("Loading catboost model from %s", model_path)
+        file_path = _model_file_path(model_path, fmt="cbm")
+        model = model_types[model_type]()
+        return model.load_model(file_path, format="cbm")
+
+
+def _model_file_path(tmp_dir: str, fmt: str) -> str:
+    return os.path.join(tmp_dir, _MODEL_PREFIX.format(fmt))
+
 
 def save_model(
     tmp_dir: str, model: "catboost.CatBoost", fmt: str, pool: Any = None
@@ -87,9 +119,9 @@ def save_model(
     https://catboost.ai/docs/concepts/python-reference_catboost_save_model.html#python-reference_catboost_save_model
     """
     logger.debug("Saving catboost model as %s", fmt)
-    target = os.path.join(tmp_dir, _MODEL_PREFIX.format(fmt))
-    model.save_model(target, format=fmt, pool=pool)
-    return target
+    file_path = _model_file_path(tmp_dir, fmt)
+    model.save_model(file_path, format=fmt, pool=pool)
+    return file_path
 
 
 def dump_attributes(tmp_dir: str, model: "catboost.CatBoost") -> str:
