@@ -1,24 +1,27 @@
-#    Copyright 2020 Neal Lathia
-
+#    Copyright 2021 Neal Lathia
+#
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
 #    You may obtain a copy of the License at
-
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-
+#
 #    Unless required by applicable law or agreed to in writing, software
 #    distributed under the License is distributed on an "AS IS" BASIS,
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
 import os
 from functools import partial
 from pathlib import Path
+from typing import Any
 
-from modelstore.models.modelmanager import ModelManager
+from modelstore.models.model_manager import ModelManager
+from modelstore.storage.storage import CloudStorage
+from modelstore.utils.log import logger
 
-LEARNER = "learner"
+LEARNER_DIRECTORY = "learner"
+LEARNER_FILE = "learner.pkl"
 
 
 class FastAIManager(ModelManager):
@@ -29,15 +32,16 @@ class FastAIManager(ModelManager):
     https://docs.fast.ai/learner.html#Learner.export
     """
 
-    @classmethod
-    def required_dependencies(cls) -> list:
-        return [
-            "fastai",
-        ]
+    NAME = "fastai"
 
-    @classmethod
-    def optional_dependencies(cls) -> list:
-        deps = super(FastAIManager, cls).optional_dependencies()
+    def __init__(self, storage: CloudStorage = None):
+        super().__init__(self.NAME, storage)
+
+    def required_dependencies(self) -> list:
+        return ["fastai"]
+
+    def optional_dependencies(self) -> list:
+        deps = super(FastAIManager, self).optional_dependencies()
         return deps + [
             "matplotlib",
             "pillow",
@@ -54,33 +58,47 @@ class FastAIManager(ModelManager):
 
     def matches_with(self, **kwargs) -> bool:
         # pylint: disable=import-outside-toplevel
-        from fastai.learner import Learner
+        import fastai
+
+        if fastai.__version__.startswith("1.0"):
+            from fastai.basic_train import Learner
+        else:
+            from fastai.learner import Learner
 
         return isinstance(kwargs.get("learner"), Learner)
 
-    def _model_info(self, **kwargs) -> dict:
-        """ Returns meta-data about the model's type """
-        return {"library": "fastai"}
-
-    def _model_data(self, **kwargs) -> dict:
-        """ Returns meta-data about the data used to train the model """
-        return {}
-
     def _get_functions(self, **kwargs) -> list:
         if not self.matches_with(**kwargs):
-            raise TypeError("learner is not a fastai.learner.Learner!")
+            raise TypeError("learner is not a fastai Learner!")
 
         return [
             partial(_save_model, learner=kwargs["learner"]),
             partial(_export_model, learner=kwargs["learner"]),
         ]
 
-    def _get_params(self, **kwargs) -> dict:
-        """
-        @ TODO: extract useful info from
-        kwargs["learner"].opt.state_dict()
-        """
-        return {}
+    def load(self, model_path: str, meta_data: dict) -> Any:
+        # pylint: disable=import-outside-toplevel
+        import fastai
+
+        if fastai.__version__.startswith("1.0"):
+            from fastai.basic_train import load_learner
+        else:
+            from fastai.learner import load_learner
+
+        version = meta_data["code"].get("dependencies", {}).get("fastai", "?")
+        if version != fastai.__version__:
+            logger.warn(
+                "Model was saved with fastai==%s, trying to load it with fastai==%s",
+                version,
+                fastai.__version__,
+            )
+
+        model_file = _model_file_path(model_path)
+        return load_learner(model_file)
+
+
+def _model_file_path(parent_dir: str) -> str:
+    return os.path.join(parent_dir, LEARNER_FILE)
 
 
 def _save_model(tmp_dir: str, learner: "fastai.learner.Leader") -> str:
@@ -88,7 +106,7 @@ def _save_model(tmp_dir: str, learner: "fastai.learner.Leader") -> str:
     learner_path = learner.path
     learner.path = Path(tmp_dir)
 
-    file_path = learner.save(LEARNER)
+    file_path = learner.save(LEARNER_DIRECTORY, with_opt=True)
 
     # Revert value
     learner.path = learner_path
@@ -96,12 +114,11 @@ def _save_model(tmp_dir: str, learner: "fastai.learner.Leader") -> str:
 
 
 def _export_model(tmp_dir: str, learner: "fastai.learner.Leader") -> str:
-    file_name = LEARNER + ".pkl"
     # learner.export(file) will write to: self.path/fname
     learner_path = learner.path
     learner.path = Path(tmp_dir)
-    learner.export(file_name)
+    learner.export(LEARNER_FILE)
 
     # Revert value
     learner.path = learner_path
-    return os.path.join(tmp_dir, file_name)
+    return _model_file_path(tmp_dir)
