@@ -11,12 +11,13 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
 import json
 import os
 from functools import partial
+from typing import Any
 
-from modelstore.models.modelmanager import ModelManager
+from modelstore.models.model_manager import ModelManager
+from modelstore.storage.storage import CloudStorage
 from modelstore.utils.log import logger
 
 MODEL_JSON = "model.json"
@@ -30,8 +31,12 @@ class LightGbmManager(ModelManager):
     https://lightgbm.readthedocs.io/en/latest/Python-Intro.html#training
     """
 
-    @classmethod
-    def required_dependencies(cls) -> list:
+    NAME = "lightgbm"
+
+    def __init__(self, storage: CloudStorage = None):
+        super().__init__(self.NAME, storage)
+
+    def required_dependencies(self) -> list:
         return ["lightgbm"]
 
     def _required_kwargs(self):
@@ -43,14 +48,6 @@ class LightGbmManager(ModelManager):
 
         return isinstance(kwargs.get("model"), lgb.Booster)
 
-    def _model_info(self, **kwargs) -> dict:
-        """ Returns meta-data about the model's type """
-        return {"library": "lightgbm", "type": type(kwargs["model"]).__name__}
-
-    def _model_data(self, **kwargs) -> dict:
-        """ Returns meta-data about the data used to train the model """
-        return {}
-
     def _get_functions(self, **kwargs) -> list:
         if not self.matches_with(**kwargs):
             raise TypeError("Model is not a lgb.Booster!")
@@ -61,17 +58,24 @@ class LightGbmManager(ModelManager):
         ]
 
     def _get_params(self, **kwargs) -> dict:
-        """
-        Returns a dictionary containing any model parameters
-        that are available
-        """
         return kwargs["model"].params
 
+    def load(self, model_path: str, meta_data: dict) -> Any:
+        # pylint: disable=import-outside-toplevel
+        import lightgbm as lgb
+
+        model_file = _model_file_path(model_path)
+        return lgb.Booster(model_file=model_file)
+
+
+def _model_file_path(parent_dir: str) -> str:
+    return os.path.join(parent_dir, MODEL_FILE)
+
 
 def save_model(tmp_dir: str, model: "lgb.Booster") -> str:
-    """From the docs: dump model into JSON file"""
+    """From the docs: dump model into a txt file"""
     logger.debug("Saving lightgbm model")
-    model_file = os.path.join(tmp_dir, MODEL_FILE)
+    model_file = _model_file_path(tmp_dir)
     model.save_model(model_file)
     return model_file
 
