@@ -11,13 +11,15 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
+import json
+import os
 from functools import partial
+from typing import Any
 
 from modelstore.meta import datasets
-from modelstore.models.common import save_joblib
-from modelstore.models.modelmanager import ModelManager
-from modelstore.models.util import convert_numpy
+from modelstore.models.common import load_joblib, save_joblib
+from modelstore.models.model_manager import ModelManager
+from modelstore.storage.storage import CloudStorage
 
 MODEL_JOBLIB = "model.joblib"
 
@@ -29,14 +31,15 @@ class SKLearnManager(ModelManager):
     https://scikit-learn.org/stable/modules/model_persistence.html
     """
 
-    @classmethod
-    def required_dependencies(cls) -> list:
+    NAME = "sklearn"
+
+    def __init__(self, storage: CloudStorage = None):
+        super().__init__(self.NAME, storage)
+
+    def required_dependencies(self) -> list:
         return ["sklearn"]
 
-    @classmethod
-    def optional_dependencies(cls) -> list:
-        """Returns a list of dependencies that, if installed
-        are useful to log info about"""
+    def optional_dependencies(self) -> list:
         deps = super().optional_dependencies()
         return deps + ["Cython", "joblib", "threadpoolctl"]
 
@@ -56,25 +59,15 @@ class SKLearnManager(ModelManager):
         except ImportError:
             pass
 
-        import sklearn
+        from sklearn.base import BaseEstimator
 
-        return isinstance(kwargs.get("model"), sklearn.base.BaseEstimator)
-
-    def _model_info(self, **kwargs) -> dict:
-        """ Returns meta-data about the model's type """
-        return {
-            "library": "sklearn",
-            "type": type(kwargs["model"]).__name__,
-        }
+        return isinstance(kwargs.get("model"), BaseEstimator)
 
     def _model_data(self, **kwargs) -> dict:
-        """ Returns meta-data about the data used to train the model """
         data = {}
         if "X_train" in kwargs:
             features = datasets.describe_dataset(kwargs["X_train"])
-            features.update(
-                _feature_importances(kwargs["model"], kwargs["X_train"])
-            )
+            features.update(_feature_importances(kwargs["model"], kwargs["X_train"]))
             data["features"] = features
         if "y_train" in kwargs:
             data["labels"] = datasets.describe_dataset(kwargs["y_train"])
@@ -84,8 +77,8 @@ class SKLearnManager(ModelManager):
         if not self.matches_with(**kwargs):
             raise TypeError("This model is not an sklearn model!")
 
-        # @TODO: export/save in onnx format?
-        return [partial(save_joblib, model=kwargs["model"], fn=MODEL_JOBLIB)]
+        # @Future idea: export/save in onnx format?
+        return [partial(save_joblib, model=kwargs["model"], file_name=MODEL_JOBLIB)]
 
     def _get_params(self, **kwargs) -> dict:
         """
@@ -93,20 +86,29 @@ class SKLearnManager(ModelManager):
         that are available
         https://scikit-learn.org/stable/modules/generated/sklearn.base.BaseEstimator.html#sklearn.base.BaseEstimator.get_params
         """
-        params = kwargs["model"].get_params()
-        # Pipelines contain a ton of things that are not JSON serializable
-        # the same params exist separately in get_params(), so we just drop
-        # the bits that could not be serialized
-        if "steps" in params:
-            for key, _ in params["steps"]:
-                params.pop(key, None)
-            params.pop("steps", None)
-        return convert_numpy(params)
+        from sklearn.pipeline import Pipeline
+
+        if isinstance(kwargs.get("model"), Pipeline):
+            # Pipelines contain a ton of things that are not JSON serializable
+            # the same params exist separately in get_params(), so we just drop
+            # the bits that could not be serialized
+            return {}
+        try:
+            params = kwargs["model"].get_params()
+            # Check if params is json serializable
+            json.dumps(params)
+            return params
+        except TypeError:
+            return {}
+
+    def load(self, model_path: str, meta_data: dict) -> Any:
+        # @Future: check if loading into same version of joblib
+        # as was used for saving
+        file_name = os.path.join(model_path, MODEL_JOBLIB)
+        return load_joblib(file_name)
 
 
-def _feature_importances(
-    model: "BaseEstimator", x_train: "pandas.DataFrame"
-) -> dict:
+def _feature_importances(model: "BaseEstimator", x_train: "pandas.DataFrame") -> dict:
     result = {}
     if datasets.is_pandas_dataframe(x_train):
         weights = _get_weights(model)
