@@ -11,12 +11,13 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
-
 import os
 from functools import partial
+from typing import Any
 
 from modelstore.models.common import save_json
-from modelstore.models.modelmanager import ModelManager
+from modelstore.models.model_manager import ModelManager
+from modelstore.storage.storage import CloudStorage
 from modelstore.utils.log import logger
 
 MODEL_FILE = "model.xgboost"
@@ -31,14 +32,15 @@ class XGBoostManager(ModelManager):
     https://xgboost.readthedocs.io/en/latest/tutorials/saving_model.html
     """
 
-    @classmethod
-    def required_dependencies(cls) -> list:
+    NAME = "xgboost"
+
+    def __init__(self, storage: CloudStorage = None):
+        super().__init__(self.NAME, storage)
+
+    def required_dependencies(self) -> list:
         return ["xgboost"]
 
-    @classmethod
-    def optional_dependencies(cls) -> list:
-        """Returns a list of dependencies that, if installed
-        are useful to log info about"""
+    def optional_dependencies(self) -> list:
         deps = super().optional_dependencies()
         return deps + ["sklearn"]
 
@@ -51,14 +53,6 @@ class XGBoostManager(ModelManager):
 
         return isinstance(kwargs.get("model"), xgb.XGBModel)
 
-    def _model_info(self, **kwargs) -> dict:
-        """ Returns meta-data about the model's type """
-        return {"library": "xgboost", "type": type(kwargs["model"]).__name__}
-
-    def _model_data(self, **kwargs) -> dict:
-        """ Returns meta-data about the data used to train the model """
-        return {}
-
     def _get_functions(self, **kwargs) -> list:
         return [
             partial(save_model, model=kwargs["model"]),
@@ -67,12 +61,32 @@ class XGBoostManager(ModelManager):
         ]
 
     def _get_params(self, **kwargs) -> dict:
-        """
-        Returns a dictionary containing any model parameters
-        that are available
-        """
         return kwargs["model"].get_xgb_params()
 
+    def load(self, model_path: str, meta_data: dict) -> Any:
+        # pylint: disable=import-outside-toplevel
+        import xgboost as xgb
+
+        model_types = {
+            "XGBRegressor": xgb.XGBRegressor,
+            "XGBClassifier": xgb.XGBClassifier,
+            "XGBModel": xgb.XGBModel,
+            # Future: other types
+        }
+        model_type = self._get_model_type(meta_data)
+        if model_type not in model_types:
+            raise ValueError(f"Cannot load xgboost model type: {model_type}")
+
+        logger.debug("Loading xgboost model from %s", model_path)
+        target = _model_file_path(model_path)
+        model = model_types[model_type]()
+        model.load_model(target)
+        return model
+
+
+def _model_file_path(tmp_dir: str) -> str:
+    return os.path.join(tmp_dir, MODEL_FILE)
+
 
 def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
     """From the docs:
@@ -80,9 +94,9 @@ def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
     among the various XGBoost interfaces.
     """
     logger.debug("Saving xgboost model")
-    target = os.path.join(tmp_dir, MODEL_FILE)
-    model.save_model(target)
-    return target
+    file_path = _model_file_path(tmp_dir)
+    model.save_model(file_path)
+    return file_path
 
 
 def dump_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
@@ -92,9 +106,7 @@ def dump_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
     """
     logger.debug("Dumping xgboost model")
     model_file = os.path.join(tmp_dir, MODEL_JSON)
-    model.get_booster().dump_model(
-        model_file, with_stats=True, dump_format="json"
-    )
+    model.get_booster().dump_model(model_file, with_stats=True, dump_format="json")
     return model_file
 
 
