@@ -13,8 +13,10 @@
 #    limitations under the License.
 import json
 import os
+from typing import Optional
 
 from modelstore.storage.blob_storage import BlobStorage
+from modelstore.storage.util import environment
 from modelstore.storage.util.versions import sorted_by_created
 from modelstore.utils.log import logger
 
@@ -36,10 +38,31 @@ class AWSStorage(BlobStorage):
     https://boto3.amazonaws.com/v1/documentation/api/latest/guide/quickstart.html
     """
 
-    def __init__(self, bucket_name: str, region: str = None):
-        super().__init__(["boto3"])
-        self.bucket_name = bucket_name
-        self.region = region
+    NAME = "aws-s3"
+    BUILD_FROM_ENVIRONMENT = {
+        "required": [
+            "MODEL_STORE_AWS_BUCKET",
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+        ],
+        "optional": [
+            "MODEL_STORE_REGION",
+            "MODEL_STORE_ROOT_PREFIX",
+        ],
+    }
+
+    def __init__(
+        self,
+        bucket_name: Optional[str] = None,
+        region: Optional[str] = None,
+        root_prefix: Optional[str] = None,
+    ):
+        super().__init__(["boto3"], root_prefix)
+        # If arguments are None, try to populate them using environment variables
+        self.bucket_name = environment.get_value(bucket_name, "MODEL_STORE_AWS_BUCKET")
+        self.region = environment.get_value(
+            region, "MODEL_STORE_REGION", allow_missing=True
+        )
         self.__client = None
 
     @property
@@ -76,6 +99,18 @@ class AWSStorage(BlobStorage):
         logger.debug("Finished: %s", destination)
         return destination
 
+    def _remove(self, destination: str) -> bool:
+        """ Removes a file from the destination path """
+        try:
+            self.client.head_object(Bucket=self.bucket_name, Key=destination)
+            self.client.delete_object(Bucket=self.bucket_name, Key=destination)
+            return True
+        except ClientError as e:
+            if int(e.response["Error"]["Code"]) != 404:
+                raise
+            logger.debug("Remote file does not exist: %s", destination)
+            return False
+
     def _storage_location(self, prefix: str) -> dict:
         """ Returns a dict of the location the artifact was stored """
         return {
@@ -92,10 +127,8 @@ class AWSStorage(BlobStorage):
 
     def _read_json_objects(self, path: str) -> list:
         results = []
-        objects = self.client.list_objects_v2(
-            Bucket=self.bucket_name, Prefix=path
-        )
-        for version in objects["Contents"]:
+        objects = self.client.list_objects_v2(Bucket=self.bucket_name, Prefix=path)
+        for version in objects.get("Contents", []):
             if not version["Key"].endswith(".json"):
                 continue
             obj = self._read_json_object(version["Key"])
