@@ -13,8 +13,10 @@
 #    limitations under the License.
 import json
 import os
+from typing import Optional
 
 from modelstore.storage.blob_storage import BlobStorage
+from modelstore.storage.util import environment
 from modelstore.storage.util.versions import sorted_by_created
 from modelstore.utils.log import logger
 
@@ -40,15 +42,25 @@ class GoogleCloudStorage(BlobStorage):
     Assumes that google.cloud.storage is installed and configured
     """
 
+    NAME = "google-cloud-storage"
+    BUILD_FROM_ENVIRONMENT = {
+        "required": ["MODEL_STORE_GCP_PROJECT", "MODEL_STORE_GCP_BUCKET"],
+        "optional": ["MODEL_STORE_ROOT_PREFIX"],
+    }
+
     def __init__(
         self,
-        project_name: str,
-        bucket_name: str,
+        project_name: Optional[str] = None,
+        bucket_name: Optional[str] = None,
+        root_prefix: Optional[str] = None,
         client: "storage.Client" = None,
     ):
-        super().__init__(["google.cloud.storage"])
-        self.project_name = project_name
-        self.bucket_name = bucket_name
+        super().__init__(["google.cloud.storage"], root_prefix)
+        # If arguments are None, try to populate them using environment variables
+        self.bucket_name = environment.get_value(bucket_name, "MODEL_STORE_GCP_BUCKET")
+        self.project_name = environment.get_value(
+            project_name, "MODEL_STORE_GCP_PROJECT"
+        )
         self.__client = client
 
     @property
@@ -108,6 +120,16 @@ class GoogleCloudStorage(BlobStorage):
         logger.debug("Finished: %s", destination)
         return destination
 
+    def _remove(self, destination: str) -> bool:
+        """ Removes a file from the destination path """
+        bucket = self.client.get_bucket(self.bucket_name)
+        blob = bucket.blob(destination)
+        if not blob.exists():
+            logger.debug("Remote file does not exist: %s", destination)
+            return False
+        blob.delete()
+        return True
+
     def _storage_location(self, prefix: str) -> dict:
         """ Returns a dict of the location the artifact was stored """
         return {
