@@ -33,9 +33,13 @@ class HostedStorage(CloudStorage):
     Usage of this storage requires you to have an `api_access_key` and `api_key_id`.
     """
 
-    def __init__(
-        self, access_key_id: Optional[str], secret_access_key: Optional[str]
-    ):
+    NAME = "hosted"
+    BUILD_FROM_ENVIRONMENT = {
+        "required": ["MODELSTORE_KEY_ID", "MODELSTORE_ACCESS_KEY"],
+        "optional": [],
+    }
+
+    def __init__(self, access_key_id: Optional[str], secret_access_key: Optional[str]):
         super().__init__([])
         self.access_key_id = _get_environ(access_key_id, "MODELSTORE_KEY_ID")
         self.secret_access_key = _get_environ(
@@ -50,12 +54,12 @@ class HostedStorage(CloudStorage):
         try:
             _ = self._post("ping", {})
             return True
-        except:
+        except Exception:
             return False
 
     def _post(self, endpoint: str, data: dict) -> dict:
         url = os.path.join(_URL_ROOT, endpoint)
-        logger.info(f"ℹ️  POST: %s", url)
+        logger.info("ℹ️  POST: %s", url)
         headers = {"x-api-key": self.secret_access_key}
         data["key_id"] = self.access_key_id
         rsp = requests.post(url, headers=headers, data=json.dumps(data))
@@ -82,9 +86,7 @@ class HostedStorage(CloudStorage):
             "type": "operator:cloud-storage",
         }
 
-    def list_versions(
-        self, domain: str, state_name: Optional[str] = None
-    ) -> list:
+    def list_versions(self, domain: str, state_name: Optional[str] = None) -> list:
         """ Returns a list of a model's versions """
         # @TODO enable filtering by state-name
         rsp = self._post("list-models", {"domain": domain})
@@ -104,6 +106,11 @@ class HostedStorage(CloudStorage):
         }
         self._post("set-metadata", data)
 
+    def get_meta_data(self, domain: str, model_id: str) -> dict:
+        """ Returns a model's meta data """
+        # @TODO Future
+        raise NotImplementedError()
+
     def download(self, local_path: str, domain: str, model_id: str = None):
         """Downloads an artifacts archive for a given (domain, model_id) pair.
         If no model_id is given, it defaults to the latest model in that
@@ -113,12 +120,17 @@ class HostedStorage(CloudStorage):
 
     def create_model_state(self, state_name: str):
         """ Creates a state label that can be used to tag models """
-        # @TODO coming soon
+        # @TODO Future
         raise NotImplementedError()
 
     def set_model_state(self, domain: str, model_id: str, state_name: str):
         """ Adds the given model ID the set that are in the state_name path """
-        # @TODO coming soon
+        # @TODO Future
+        raise NotImplementedError()
+
+    def unset_model_state(self, domain: str, model_id: str, state_name: str):
+        """ Removes the given model ID from the set that are in the state_name path """
+        # @TODO Future
         raise NotImplementedError()
 
 
