@@ -16,11 +16,11 @@ import os
 import shutil
 import warnings
 from pathlib import Path
+from typing import Optional
 
 from modelstore.storage.blob_storage import BlobStorage
 from modelstore.storage.util.paths import (
-    MODELSTORE_ROOT,
-    get_metadata_path,
+    MODELSTORE_ROOT_PREFIX,
     get_model_state_path,
     is_valid_state_name,
 )
@@ -31,40 +31,68 @@ from modelstore.utils.log import logger
 class FileSystemStorage(BlobStorage):
 
     """
-    File System Storage
+    File System Storage: store models in a directory
     """
 
-    def __init__(self, root_path: str):
-        super().__init__([])
-        if MODELSTORE_ROOT in root_path:
+    NAME = "filesystem"
+    BUILD_FROM_ENVIRONMENT = {
+        "required": [
+            "MODEL_STORE_ROOT_PREFIX",
+        ],
+        "optional": [],
+    }
+
+    def __init__(self, root_dir: Optional[str] = None):
+        super().__init__([], root_prefix=root_dir)
+        if self.root_prefix == "":
+            raise Exception(
+                "Error: cannot create a file system model store without a root directory"
+            )
+        if MODELSTORE_ROOT_PREFIX in self.root_prefix:
             warnings.warn(
-                f'Warning: "{MODELSTORE_ROOT}" is in the root path, and is a value'
+                f'Warning: "{MODELSTORE_ROOT_PREFIX}" is in the root path, and is a value'
                 + " that this library usually appends. Is this intended?"
             )
-        root_path = os.path.abspath(root_path)
-        self.root_dir = root_path
-        logger.debug("Root is: %s", self.root_dir)
+        self.root_prefix = os.path.abspath(self.root_prefix)
 
     def validate(self) -> bool:
-        """This validates that the directory exists
-        and can be written to"""
+        """This validates that the directory exists and can be written to"""
         # pylint: disable=broad-except
-        try:
-            parent_dir = os.path.split(self.root_dir)[0]
-            # Check that directory exists
-            if not os.path.exists(parent_dir):
-                logger.error("Error: %s does not exist", parent_dir)
-                return False
+        # Check that the directory exists & we can write to it
+        if not os.path.exists(self.root_prefix):
+            raise Exception(
+                "Error: Parent directory to root dir '%s' does not exist",
+                self.root_prefix,
+            )
+        if not os.path.isdir(self.root_prefix):
+            raise Exception("Error: root_dir needs to be a directory")
 
+        try:
             # Check we can write to it
-            source = os.path.join(self.root_dir, ".operator-ai")
+            source = os.path.join(self.root_prefix, ".operator-ai")
             Path(source).touch()
             os.remove(source)
             return True
         except Exception as ex:
-            logger.error("Error=%s...", str(ex))
+            logger.error(ex)
             return False
 
+    def _get_metadata_path(
+        self, domain: str, model_id: str, state_name: Optional[str] = None
+    ) -> str:
+        """Creates a path where a meta-data file about a model is stored.
+        I.e.: :code:`operatorai-model-store/<domain>/versions/<model-id>.json`
+
+        Args:
+            domain (str): A group of models that are trained for the
+            same end-use are given the same domain.
+
+            model_id (str): A UUID4 string that identifies this specific
+            model.
+        """
+        meta_data_path = super()._get_metadata_path(domain, model_id, state_name)
+        return self.relative_dir(meta_data_path)
+
     def _push(self, source: str, destination: str) -> str:
         destination = self.relative_dir(destination)
 
@@ -76,6 +104,15 @@ class FileSystemStorage(BlobStorage):
         shutil.copy(source, destination)
         return os.path.join(os.path.abspath(destination), file_name)
 
+    def _remove(self, destination: str) -> bool:
+        """ Removes a file from the destination path """
+        destination = self.relative_dir(destination)
+        if not os.path.exists(destination):
+            logger.debug("Remote file does not exist: %s", destination)
+            return False
+        os.remove(destination)
+        return True
+
     def _read_json_objects(self, path: str) -> list:
         path = self.relative_dir(path)
         if not os.path.exists(path):
@@ -92,16 +129,16 @@ class FileSystemStorage(BlobStorage):
 
     def relative_dir(self, file_path: str) -> str:
         paths = os.path.split(file_path)
-        parent_dir = os.path.join(self.root_dir, paths[0])
+        parent_dir = os.path.join(self.root_prefix, paths[0])
         if not os.path.exists(parent_dir):
             os.makedirs(parent_dir)
         return os.path.join(parent_dir, paths[1])
 
-    def _storage_location(self, archive_path: str) -> dict:
+    def _storage_location(self, prefix: str) -> dict:
         """ Returns a dict of the location the artifact was stored """
         return {
             "type": "file_system",
-            "path": os.path.abspath(archive_path),
+            "path": os.path.abspath(self.relative_dir(prefix)),
         }
 
     def _get_storage_location(self, meta: dict) -> str:
@@ -116,19 +153,12 @@ class FileSystemStorage(BlobStorage):
         """ Returns whether a model state with name state_name exists """
         if not is_valid_state_name(state_name):
             return False
-        state_path = self.relative_dir(get_model_state_path(state_name))
-        return os.path.exists(state_path)
-
-    def set_model_state(self, domain: str, model_id: str, state_name: str):
-        """ Adds the given model ID the set that are in the state_name path """
-        if not self.state_exists(state_name):
-            logger.debug("Model state '%s' does not exist", state_name)
-            raise Exception(f"State '{state_name}' does not exist")
-        model_path = self.relative_dir(get_metadata_path(domain, model_id))
-        model_state_path = self.relative_dir(
-            get_metadata_path(domain, model_id, state_name)
+        # @TODO this function can be removed once get_model_state_path
+        # doesn't need to be called with relative_dir()
+        state_path = self.relative_dir(
+            get_model_state_path(self.root_prefix, state_name)
         )
-        shutil.copy(model_path, model_state_path)
+        return os.path.exists(state_path)
 
 
 def _read_json_file(path: str) -> dict:
