@@ -12,7 +12,7 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 from abc import ABC, ABCMeta, abstractmethod
-from typing import Optional
+from typing import Optional, Union
 
 from modelstore.meta.dependencies import module_exists
 
@@ -38,8 +38,16 @@ class CloudStorage(ABC):
         raise NotImplementedError()
 
     @abstractmethod
-    def upload(self, domain: str, model_id: str, local_path: str) -> dict:
-        """ Uploads an archive to this type of storage"""
+    def upload(
+        self,
+        domain: str,
+        local_path: str,
+        extras: Optional[Union[str, list]] = None,
+    ) -> dict:
+        """Uploads an archive to this type of storage
+        :param extras can be a path to a file or list of files
+        if these are specified, those files are upload
+        to the same storage prefix too."""
         raise NotImplementedError()
 
     @abstractmethod
@@ -47,6 +55,11 @@ class CloudStorage(ABC):
         """ Annotates a model with some given meta data """
         raise NotImplementedError()
 
+    @abstractmethod
+    def get_meta_data(self, domain: str, model_id: str) -> dict:
+        """ Returns a model's meta data """
+        raise NotImplementedError()
+
     @abstractmethod
     def download(self, local_path: str, domain: str, model_id: str = None):
         """Downloads an artifacts archive for a given (domain, model_id) pair.
@@ -75,3 +88,8 @@ class CloudStorage(ABC):
     def set_model_state(self, domain: str, model_id: str, state_name: str):
         """ Sets the given model ID to the given state """
         raise NotImplementedError()
+
+    @abstractmethod
+    def unset_model_state(self, domain: str, model_id: str, state_name: str):
+        """ Removes the given model ID from the set that are in the state_name path """
+        raise NotImplementedError()
