@@ -17,10 +17,12 @@ from typing import Optional
 
 from modelstore.utils.log import logger
 
-MODELSTORE_ROOT = "operatorai-model-store"
+MODELSTORE_ROOT_PREFIX = "operatorai-model-store"
+
+# @TODO move into blob_storage / override in local
 
 
-def get_archive_path(domain: str, local_path: str) -> str:
+def get_archive_path(root_dir: str, domain: str, local_path: str) -> str:
     """Creates a bucket prefix where a model archive will be stored.
     I.e.: :code:`operatorai-model-store/<domain>/<prefix>/<file-name>`
 
@@ -35,10 +37,12 @@ def get_archive_path(domain: str, local_path: str) -> str:
     # Future: enable different types of prefixes
     # Warning! Mac OS translates ":" in paths to "/"
     prefix = datetime.now().strftime("%Y/%m/%d/%H:%M:%S")
-    return os.path.join(MODELSTORE_ROOT, domain, prefix, file_name)
+    return os.path.join(root_dir, MODELSTORE_ROOT_PREFIX, domain, prefix, file_name)
 
 
-def get_versions_path(domain: str, state_name: Optional[str] = None) -> str:
+def get_versions_path(
+    root_dir: str, domain: str, state_name: Optional[str] = None
+) -> str:
     """Creates a path where a meta-data file about a model is stored.
     I.e.: :code:`operatorai-model-store/<domain>/versions/`
 
@@ -48,35 +52,20 @@ def get_versions_path(domain: str, state_name: Optional[str] = None) -> str:
         state_name (str): A model's state tag (e.g. "prod" or "archived")
     """
     if state_name is not None:
-        return os.path.join(MODELSTORE_ROOT, domain, "versions", state_name)
-    return os.path.join(MODELSTORE_ROOT, domain, "versions")
+        return os.path.join(
+            root_dir, MODELSTORE_ROOT_PREFIX, domain, "versions", state_name
+        )
+    return os.path.join(root_dir, MODELSTORE_ROOT_PREFIX, domain, "versions")
 
 
-def get_metadata_path(
-    domain: str, model_id: str, state_name: Optional[str] = None
-) -> str:
-    """Creates a path where a meta-data file about a model is stored.
-    I.e.: :code:`operatorai-model-store/<domain>/versions/<model-id>.json`
-
-    Args:
-        domain (str): A group of models that are trained for the
-        same end-use are given the same domain.
-
-        model_id (str): A UUID4 string that identifies this specific
-        model.
-    """
-    versions_path = get_versions_path(domain, state_name)
-    return os.path.join(versions_path, f"{model_id}.json")
-
-
-def get_domains_path() -> str:
+def get_domains_path(root_dir: str) -> str:
     """Creates a path where meta-data about the latest trained model
     is stored, i.e.: :code:`operatorai-model-store/domains/`
     """
-    return os.path.join(MODELSTORE_ROOT, "domains")
+    return os.path.join(root_dir, MODELSTORE_ROOT_PREFIX, "domains")
 
 
-def get_domain_path(domain: str) -> str:
+def get_domain_path(root_dir: str, domain: str) -> str:
     """Creates a path where meta-data about the latest trained model
     is stored, i.e.: :code:`operatorai-model-store/domains/<domain>.json`
 
@@ -84,11 +73,11 @@ def get_domain_path(domain: str) -> str:
         domain (str): A group of models that are trained for the
         same end-use are given the same domain.
     """
-    domains_path = get_domains_path()
+    domains_path = get_domains_path(root_dir)
     return os.path.join(domains_path, f"{domain}.json")
 
 
-def get_model_states_path() -> str:
+def get_model_states_path(root_dir: str) -> str:
     """Creates a path where meta-data about the model states are
     stored, i.e.: :code:`operatorai-model-store/model_states/`
 
@@ -96,17 +85,17 @@ def get_model_states_path() -> str:
         domain (str): A group of models that are trained for the
         same end-use are given the same domain.
     """
-    return os.path.join(MODELSTORE_ROOT, "model_states")
+    return os.path.join(root_dir, MODELSTORE_ROOT_PREFIX, "model_states")
 
 
-def get_model_state_path(state_name: str) -> str:
+def get_model_state_path(root_dir: str, state_name: str) -> str:
     """Creates a path where meta-data about a model states is
     stored, i.e.: :code:`operatorai-model-store/model_states/<state_name>.json`
 
     Args:
         state_name (str): The name of the model state (e.g., "prod").
     """
-    model_states = get_model_states_path()
+    model_states = get_model_states_path(root_dir)
     return os.path.join(model_states, f"{state_name}.json")
 
 
