@@ -16,6 +16,7 @@ import os
 import pytest
 import torch
 from modelstore.models.pytorch import (
+    MODEL_PT,
     PyTorchManager,
     _save_model,
     _save_state_dict,
@@ -48,6 +49,12 @@ class ExampleNet(nn.Module):
         return x
 
 
+def assert_models_equal(model_a: nn.Module, model_b: nn.Module):
+    assert type(model_a) == type(model_b)
+    for a_params, lb_params in zip(model_a.parameters(), model_b.parameters()):
+        assert a_params.data.ne(lb_params.data).sum() == 0
+
+
 @pytest.fixture
 def pytorch_model():
     return ExampleNet()
@@ -59,38 +66,52 @@ def pytorch_optim(pytorch_model):
 
 
 @pytest.fixture
-def torch_manager():
+def pytorch_manager():
     return PyTorchManager()
 
 
-def test_model_info(torch_manager, pytorch_model):
-    exp = {"library": "pytorch"}
-    res = torch_manager._model_info(model=pytorch_model)
+def test_model_info(pytorch_manager, pytorch_model):
+    exp = {"library": "pytorch", "type": "ExampleNet"}
+    res = pytorch_manager._model_info(model=pytorch_model)
     assert exp == res
 
 
-def test_model_data(torch_manager, pytorch_model):
+@pytest.mark.parametrize(
+    "ml_library,should_match",
+    [
+        ("pytorch", True),
+        ("sklearn", False),
+    ],
+)
+def test_is_same_library(pytorch_manager, ml_library, should_match):
+    assert (
+        pytorch_manager._is_same_library({"library": ml_library})
+        == should_match
+    )
+
+
+def test_model_data(pytorch_manager, pytorch_model):
     exp = {}
-    res = torch_manager._model_data(model=pytorch_model)
+    res = pytorch_manager._model_data(model=pytorch_model)
     assert exp == res
 
 
-def test_required_kwargs(torch_manager):
-    assert torch_manager._required_kwargs() == ["model", "optimizer"]
+def test_required_kwargs(pytorch_manager):
+    assert pytorch_manager._required_kwargs() == ["model"]
 
 
-def test_matches_with(torch_manager, pytorch_model, pytorch_optim):
-    assert torch_manager.matches_with(
+def test_matches_with(pytorch_manager, pytorch_model, pytorch_optim):
+    assert pytorch_manager.matches_with(
         model=pytorch_model, optimizer=pytorch_optim
     )
-    assert not torch_manager.matches_with(model="a-string-value")
-    assert not torch_manager.matches_with(classifier=pytorch_model)
+    assert not pytorch_manager.matches_with(model="a-string-value")
+    assert not pytorch_manager.matches_with(classifier=pytorch_model)
 
 
-def test_get_functions(torch_manager, pytorch_model, pytorch_optim):
+def test_get_functions(pytorch_manager, pytorch_model, pytorch_optim):
     assert (
         len(
-            torch_manager._get_functions(
+            pytorch_manager._get_functions(
                 model=pytorch_model, optimizer=pytorch_optim
             )
         )
@@ -98,26 +119,21 @@ def test_get_functions(torch_manager, pytorch_model, pytorch_optim):
     )
 
 
-def test_get_params(torch_manager, pytorch_model, pytorch_optim):
+def test_get_params(pytorch_manager, pytorch_model, pytorch_optim):
     exp = pytorch_optim.state_dict()
-    res = torch_manager._get_params(
+    res = pytorch_manager._get_params(
         model=pytorch_model, optimizer=pytorch_optim
     )
     assert exp == res
 
 
-def models_equal(model_a: nn.Module, module_b: nn.Module):
-    for a_params, lb_params in zip(model_a.parameters(), module_b.parameters()):
-        assert a_params.data.ne(lb_params.data).sum() == 0
-
-
 def test_save_model(pytorch_model, tmp_path):
     exp = os.path.join(tmp_path, "model.pt")
     file_path = _save_model(tmp_path, pytorch_model)
     assert exp == file_path
 
     model = torch.load(file_path)
-    models_equal(pytorch_model, model)
+    assert_models_equal(pytorch_model, model)
 
 
 def test_save_state_dict(pytorch_model, pytorch_optim, tmp_path):
@@ -129,4 +145,27 @@ def test_save_state_dict(pytorch_model, pytorch_optim, tmp_path):
     model = ExampleNet()
 
     model.load_state_dict(state_dict["model_state_dict"])
-    models_equal(pytorch_model, model)
+    assert_models_equal(pytorch_model, model)
+
+
+def test_save_state_dict_without_optimizer(pytorch_model, tmp_path):
+    exp = os.path.join(tmp_path, "checkpoint.pt")
+    file_path = _save_state_dict(tmp_path, pytorch_model)
+    assert file_path == exp
+
+    state_dict = torch.load(file_path)
+    model = ExampleNet()
+
+    model.load_state_dict(state_dict["model_state_dict"])
+    assert_models_equal(pytorch_model, model)
+
+
+def test_load_model(tmp_path, pytorch_manager, pytorch_model):
+    # Save the model to a tmp directory
+    torch.save(pytorch_model, os.path.join(tmp_path, MODEL_PT))
+
+    #  Load the model
+    loaded_model = pytorch_manager.load(tmp_path, {})
+
+    # Expect the two to be the same
+    assert_models_equal(pytorch_model, loaded_model)
