@@ -11,20 +11,19 @@
 #    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
+import json
 import os
 
-import pytest
-
 # pylint: disable=redefined-outer-name
 TEST_FILE_NAME = "test-file.txt"
-TEST_FILE_CONTENTS = "expected-contents"
+TEST_FILE_CONTENTS = json.dumps({"k": "v"})
+TEST_FILE_LIST = [f"test-file-{i}.json" for i in range(3)]
 
 
-@pytest.fixture
-def temp_file(tmp_path):
+def temp_file(tmp_path, contents=TEST_FILE_CONTENTS):
     source = os.path.join(tmp_path, TEST_FILE_NAME)
     with open(source, "w") as out:
-        out.write(TEST_FILE_CONTENTS)
+        out.write(contents)
     return source
 
 
@@ -34,11 +33,9 @@ def file_contains_expected_contents(file_path):
     return contents == TEST_FILE_CONTENTS
 
 
-@pytest.fixture
 def remote_path():
     return "prefix/to/file/"
 
 
-@pytest.fixture
-def remote_file_path(remote_path):
-    return os.path.join(remote_path, TEST_FILE_NAME)
+def remote_file_path():
+    return os.path.join(remote_path(), TEST_FILE_NAME)
